"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.keyDidBls12381g1g2 = void 0;
exports.getBls12381g1g2VerificationMethod = getBls12381g1g2VerificationMethod;
const Key_1 = require("../../../../crypto/Key");
const KeyType_1 = require("../../../../crypto/KeyType");
const error_1 = require("../../../../error");
const verificationMethod_1 = require("../verificationMethod");
function getBls12381g1g2VerificationMethod(did, key) {
    const g1PublicKey = key.publicKey.slice(0, 48);
    const g2PublicKey = key.publicKey.slice(48);
    const bls12381g1Key = Key_1.Key.fromPublicKey(g1PublicKey, KeyType_1.KeyType.Bls12381g1);
    const bls12381g2Key = Key_1.Key.fromPublicKey(g2PublicKey, KeyType_1.KeyType.Bls12381g2);
    const bls12381g1VerificationMethod = (0, verificationMethod_1.getBls12381G1Key2020)({
        id: `${did}#${bls12381g1Key.fingerprint}`,
        key: bls12381g1Key,
        controller: did,
    });
    const bls12381g2VerificationMethod = (0, verificationMethod_1.getBls12381G2Key2020)({
        id: `${did}#${bls12381g2Key.fingerprint}`,
        key: bls12381g2Key,
        controller: did,
    });
    return [bls12381g1VerificationMethod, bls12381g2VerificationMethod];
}
exports.keyDidBls12381g1g2 = {
    supportedVerificationMethodTypes: [],
    // For a G1G2 key, we return two verification methods
    getVerificationMethods: getBls12381g1g2VerificationMethod,
    getKeyFromVerificationMethod: () => {
        throw new error_1.CredoError('Not supported for bls12381g1g2 key');
    },
};
//# sourceMappingURL=bls12381g1g2.js.map