import type { StoreCredentialOptions, W3cCreatePresentationOptions, W3cSignCredentialOptions, W3cSignPresentationOptions, W3cVerifyCredentialOptions, W3cVerifyPresentationOptions } from './W3cCredentialServiceOptions';
import type { W3cVerifiableCredential, ClaimFormat } from './models';
import type { W3cCredentialRecord } from './repository';
import type { Query, QueryOptions } from '../../storage/StorageService';
import { AgentContext } from '../../agent';
import { W3cCredentialService } from './W3cCredentialService';
/**
 * @public
 */
export declare class W3cCredentialsApi {
    private agentContext;
    private w3cCredentialService;
    constructor(agentContext: AgentContext, w3cCredentialService: W3cCredentialService);
    storeCredential(options: StoreCredentialOptions): Promise<W3cCredentialRecord>;
    removeCredentialRecord(id: string): Promise<void>;
    getAllCredentialRecords(): Promise<W3cCredentialRecord[]>;
    getCredentialRecordById(id: string): Promise<W3cCredentialRecord>;
    findCredentialRecordsByQuery(query: Query<W3cCredentialRecord>, queryOptions?: QueryOptions): Promise<W3cVerifiableCredential[]>;
    signCredential<Format extends ClaimFormat.JwtVc | ClaimFormat.LdpVc>(options: W3cSignCredentialOptions<Format>): Promise<W3cVerifiableCredential<Format>>;
    verifyCredential(options: W3cVerifyCredentialOptions): Promise<import("./models").W3cVerifyCredentialResult>;
    createPresentation(options: W3cCreatePresentationOptions): Promise<import("./models").W3cPresentation>;
    signPresentation<Format extends ClaimFormat.JwtVp | ClaimFormat.LdpVp>(options: W3cSignPresentationOptions<Format>): Promise<import("./models").W3cVerifiablePresentation<Format>>;
    verifyPresentation(options: W3cVerifyPresentationOptions): Promise<import("./models").W3cVerifyPresentationResult>;
}
